package au.com.postnewspapers.pgclientcertdemo;

import java.sql.Connection;
import java.sql.DriverManager;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.sql.Statement;
import java.util.Properties;

/**
 * Establish a connection to the server using the parameters
 * supplied by the test invoker. In particular, a custom
 * SSLSocketFactory may be requested.
 * 
 * @author Craig Ringer <craig@postnewspapers.com.au>
 */
public class TestConnection {

    private static final String pgJdbcDriver = "org.postgresql.Driver";
    private String pgJdbcURL;
    private String sslSocketFactoryClass = null;

    public void setURL(String url) {
        if (url.contains("sslfactory=")) {
            throw new IllegalArgumentException("JDBC URL may not specify any SSLSocketFactory (sslfactory= param)");
        }
        this.pgJdbcURL = url;
    }

    public void setSSLSocketFactoryClass(String className) {
        this.sslSocketFactoryClass = className;
    }

    public String getServerVersion() throws ClassNotFoundException, SQLException {
        // Load the JDBC driver if it's not already loaded.
        // Class.forName doesn't work properly in Java Web Start or any
        // other environment where the system classloader isn't necessarily
        // aware of all resources. Use the classloader that loaded our class
        // instead.
        this.getClass().getClassLoader().loadClass(pgJdbcDriver);
        // Prepare a properties map for the connection. We use
        // this map to set up the SSL socket factory and any other
        // params not included directly in the URL.
        Properties connProps = new Properties();
        if (sslSocketFactoryClass != null)
            connProps.setProperty("sslfactory", sslSocketFactoryClass);
        Connection conn = DriverManager.getConnection(pgJdbcURL, connProps);
        // Error handling? What's that? We're just going to throw anyway.
        Statement stmt = conn.createStatement();
        stmt.execute("SELECT version()");
        ResultSet rs = stmt.getResultSet();
        rs.next();
        String pgServerVersion = rs.getString(1);
        rs.close();
        stmt.close();
        conn.close();
        return pgServerVersion;
    }

}
